from typing import Any,List,Optional
import joblib
from fastapi import APIRouter, HTTPException
from loguru import logger


from model.prediction import HealthResponse, MachineLearningReponse
from core.errors import PredictException
from services.predict import MachineLearningModel

router = APIRouter()
model = MachineLearningModel()

get_prediction = lambda data_input: MachineLearningReponse(
    model.predict(data_input)
)

@router.post("/predict", response_model=MachineLearningReponse, name="predict:get-prediction")
async def predict(data_input : List[float] = None) -> MachineLearningReponse:
    if not data_input:
        raise HTTPException(status_code=404, detail=f"'data_input' argument invalid!")
    try:
        # prediction = get_prediction(data_input)
        prediction = model.predict(data_input)
    except Exception as e:
        raise ValueError("Hello")
        raise HTTPException(status_code=500, detail=f"Exception: {e}")

    return MachineLearningReponse(prediction = prediction)


@router.get("/health", response_model= HealthResponse, name = "health:get-data")
async def health_check():
    is_health = False
    try:
        input_sample = [6.2,2.8,4.8,1.8]
        # get_prediction(input_sample)
        prediction = model.predict(data_input)
        is_health = True
        return HealthResponse(status = is_health)
    except Exception:
        raise HTTPException(status_code=404, detail="Unhealthy")



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['anscenter',
 'anscenter.app',
 'anscenter.app.api',
 'anscenter.app.api.routes',
 'anscenter.app.core',
 'anscenter.app.model',
 'anscenter.app.services']

package_data = \
{'': ['*'], 'anscenter': ['ml/libs/*', 'ml/model/*']}

install_requires = \
['fastapi[testclient]>=0.68.1,<0.69.0',
 'joblib>=1.0.1,<2.0.0',
 'loguru>=0.4.0,<0.5.0',
 'pydantic>=1.3,<2.0',
 'pytest>=6.2.4,<7.0.0',
 'requests>=2.22.0,<3.0.0',
 'uvicorn>=0.11.1,<0.12.0']

setup_kwargs = {
    'name': 'anscenter',
    'version': '0.1.6',
    'description': 'Backend module for ANSCENTER project',
    'long_description': '# backend-module\n\nMain backend module, which is used for developing web-app logic and deploying AI model.\n\n## Installation\nRun the following to install:\n```python\npip install anscenter\n```\n\n## Usage\n```python\nfrom anscester.predict import MachineLearningModel\n\n# Generate model\nmodel = MachineLearningModel()\n\n# Using Example\ndata_input = [1.0, 2.0, 3.0, 4.0]\nresult = model.predict(data_input)\nprint(result)\n```\n\n## Developing HelloG\nTo install helloG, along with the tools you need to develop and run tests, run the following in your virtualenv:\n```bash\n$ pip install anscenter[dev]\n```',
    'author': 'ARI Technology',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
